@@ -15,7 +15,7 @@
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 
-from PySide.QtGui import QApplication, QDialog, QWidget, QScrollArea, QGridLayout, QLabel, QVBoxLayout, QImage, QPixmap
+from PySide.QtGui import QDialog, QWidget, QScrollArea, QGridLayout, QLabel, QVBoxLayout, QImage, QPixmap
 from PySide.QtCore import Qt
 from custom_widgets import Ruler
 import foursquare
@@ -85,4 +85,4 @@ THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH RE
         gridLayout.addWidget(poweredbyLabel, i, 0, Qt.AlignHCenter)
         i +=1
 
-        gridLayout.addWidget(foursquareDisclaimerLabel, i, 0)
\ No newline at end of file
+        gridLayout.addWidget(foursquareDisclaimerLabel, i, 0)
