@@ -17,7 +17,6 @@
 import sys
 from PySide.QtCore import *
 from PySide.QtGui import *
-from PySide.QtGui import QCheckBox
 
 from PySide.QtMaemo5 import QMaemo5ValueButton, QMaemo5InformationBox
 
@@ -36,7 +35,7 @@ class Profile(QWidget):
     def __init__(self, parent=None):
         super(Profile, self).__init__(parent)
         self.manualUpdate = False
-        self.user = foursquare.get_user("self", foursquare.CacheOrGet)['user']
+        self.user = foursquare.get_user("self", foursquare.Cache.CacheOrGet)['user']
         self.photo_label = QLabel()
 
         self.textLabel = QLabel()
@@ -96,7 +95,7 @@ class Profile(QWidget):
             location = self.user['checkins']['items'][0]['venue']['name']
             lastSeen = self.user['checkins']['items'][0]['createdAt']
             lastSeen = datetime.fromtimestamp(lastSeen).strftime("%Y-%m-%d %X")
-            location = "Last seen @" +  location # + "</b>, at <i>" + lastSeen + "</i>"
+            location = "Last seen @" + location # + "</b>, at <i>" + lastSeen + "</i>"
         else:
             location = "Never checked in anywhere!"
 
@@ -138,13 +137,16 @@ class MainWindow(UberSquareWindow):
         previous_venues_button = QPushButton("Visited")
         previous_venues_button.setIcon(QIcon.fromTheme("general_clock"))
         self.connect(previous_venues_button, SIGNAL("clicked()"), self.previous_venues_pushed)
+        self._previous_venues = False
 
         todo_venues_button = QPushButton("To-Do List")
         todo_venues_button.setIcon(QIcon.fromTheme("calendar_todo"))
         self.connect(todo_venues_button, SIGNAL("clicked()"), self.todo_venues_pushed)
+        self._todo_venues = False
 
         search_venues_button = QPushButton("Search/Explore")
         self.connect(search_venues_button, SIGNAL("clicked()"), self.search_venues_pushed)
+        self.searchDialog = SearchDialog(self)
 
         self.location_button = SignalEmittingValueButton("Location", self.locationSelected, self)
         self.location_button.setPickSelector(LocationProviderSelector())
@@ -237,8 +239,8 @@ class MainWindow(UberSquareWindow):
             self.showWaitingDialog.emit()
 
     def logout_pushed(self):
-        config_del("code")
-        config_del("access_token")
+        foursquare.config_del("code")
+        foursquare.config_del("access_token")
         msgBox = QMessageBox()
         msgBox.setText("I've gotten rid of your credentials. I'm going to close now, and if you run me again, it'll be like our first time all over again. Bye!")
         msgBox.setWindowTitle("Credentials forgotten")
@@ -247,36 +249,37 @@ class MainWindow(UberSquareWindow):
 
     def previous_venues_pushed(self):
         venues = foursquare.get_history(foursquare.CacheOrNull)
-        w = VenueListWindow("Visited Venues", venues, self)
-        t = VenueProviderThread(w, foursquare.get_history, self)
+        if not self._previous_venues:
+            self._previous_venues = VenueListWindow("Visited Venues", venues, self)
+        t = VenueProviderThread(self._previous_venues, foursquare.get_history, self)
         t.start()
         if venues:
-            w.show()
+            self._previous_venues.show()
         else:
             self.showWaitingDialog.emit()
 
     def todo_venues_pushed(self):
         try:
             venues = foursquare.lists_todos(foursquare.CacheOrNull)
-            w = VenueListWindow("To-Do Venues", venues, self)
-            t = VenueProviderThread(w, foursquare.lists_todos, self)
+            if not self._todo_venues:
+                self._todo_venues = VenueListWindow("To-Do Venues", venues, self)
+            t = VenueProviderThread(self._todo_venues, foursquare.lists_todos, self)
             t.start()
             if venues:
-                w.show()
+                self._todo_venues.show()
             else:
                 self.showWaitingDialog.emit()
         except IOError:
             self.networkError.emit()
 
     def search_venues_pushed(self):
-        dialog = SearchDialog(self)
-        dialog.exec_()
+        self.searchDialog.exec_()
 
-        if (dialog.result() != QDialog.Accepted):
+        if (self.searchDialog.result() != QDialog.Accepted):
             return None
 
-        venueName = dialog.text().encode('utf-8')
-        categoryId = dialog.category()
+        venueName = self.searchDialog.text().encode('utf-8')
+        categoryId = self.searchDialog.category()
         ll = LocationProvider().get_ll()
 
         try:
@@ -319,10 +322,10 @@ class MainWindow(UberSquareWindow):
 
 
 class SettingsDialog(UberSquareWindow):
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         super(SettingsDialog, self).__init__(parent)
         self.setWindowTitle("Settings")
-        
+
         self.cw = QWidget(self)
         self.setCentralWidget(self.cw)
 
